@@ -2,6 +2,7 @@ from __future__ import print_function, division, absolute_import
 
 import atexit
 import logging
+import multiprocessing
 import gc
 import os
 from sys import exit
@@ -10,14 +11,9 @@ import warnings
 import click
 import dask
 from distributed import Nanny, Worker
-from distributed.utils import get_ip_interface, parse_timedelta
-from distributed.worker import _ncores
+from distributed.utils import parse_timedelta
 from distributed.security import Security
-from distributed.cli.utils import (
-    check_python_3,
-    uri_from_host_port,
-    install_signal_handlers,
-)
+from distributed.cli.utils import check_python_3, install_signal_handlers
 from distributed.comm import get_address_host_port
 from distributed.preloading import validate_preload_argv
 from distributed.proctitle import (
@@ -74,12 +70,19 @@ pem_file_option_type = click.Path(exists=True, resolve_path=True)
     help="Address on which to listen for diagnostics dashboard",
 )
 @click.option(
-    "--bokeh/--no-bokeh",
-    "bokeh",
+    "--dashboard/--no-dashboard",
+    "dashboard",
     default=True,
     show_default=True,
     required=False,
-    help="Launch Bokeh Web UI",
+    help="Launch the Dashboard",
+)
+@click.option(
+    "--bokeh/--no-bokeh",
+    "bokeh",
+    default=None,
+    help="Deprecated.  See --dashboard/--no-dashboard.",
+    required=False,
 )
 @click.option(
     "--listen-address",
@@ -108,6 +111,9 @@ pem_file_option_type = click.Path(exists=True, resolve_path=True)
 @click.option(
     "--interface", type=str, default=None, help="Network interface like 'eth0' or 'ib0'"
 )
+@click.option(
+    "--protocol", type=str, default=None, help="Protocol like tcp, tls, or ucx"
+)
 @click.option("--nthreads", type=int, default=0, help="Number of threads per process.")
 @click.option(
     "--nprocs",
@@ -118,7 +124,7 @@ pem_file_option_type = click.Path(exists=True, resolve_path=True)
 @click.option(
     "--name",
     type=str,
-    default="",
+    default=None,
     help="A unique name for this worker like 'worker-1'. "
     "If used with --nprocs then the process number "
     "will be appended like name-0, name-1, name-2, ...",
@@ -167,7 +173,9 @@ pem_file_option_type = click.Path(exists=True, resolve_path=True)
     default=None,
     help="Seconds to wait for a scheduler before closing",
 )
-@click.option("--bokeh-prefix", type=str, default=None, help="Prefix for the bokeh app")
+@click.option(
+    "--dashboard-prefix", type=str, default="", help="Prefix for the dashboard"
+)
 @click.option(
     "--preload",
     type=str,
@@ -179,6 +187,7 @@ pem_file_option_type = click.Path(exists=True, resolve_path=True)
 @click.argument(
     "preload_argv", nargs=-1, type=click.UNPROCESSED, callback=validate_preload_argv
 )
+@click.version_option()
 def main(
     scheduler,
     host,
@@ -194,15 +203,17 @@ def main(
     pid_file,
     reconnect,
     resources,
+    dashboard,
     bokeh,
     bokeh_port,
     local_directory,
     scheduler_file,
     interface,
+    protocol,
     death_timeout,
     preload,
     preload_argv,
-    bokeh_prefix,
+    dashboard_prefix,
     tls_ca_file,
     tls_cert,
     tls_key,
@@ -220,6 +231,11 @@ def main(
             "Consider adding ``--dashboard-address :%d`` " % bokeh_port
         )
         dashboard_address = bokeh_port
+    if bokeh is not None:
+        warnings.warn(
+            "The --bokeh/--no-bokeh flag has been renamed to --dashboard/--no-dashboard. "
+        )
+        dashboard = bokeh
 
     sec = Security(
         tls_ca_file=tls_ca_file, tls_worker_cert=tls_cert, tls_worker_key=tls_key
@@ -278,7 +294,7 @@ def main(
         port = worker_port
 
     if not nthreads:
-        nthreads = _ncores // nprocs
+        nthreads = multiprocessing.cpu_count() // nprocs
 
     if pid_file:
         with open(pid_file, "w") as f:
@@ -292,18 +308,6 @@ def main(
 
     services = {}
 
-    if bokeh:
-        try:
-            from distributed.bokeh.worker import BokehWorker
-        except ImportError:
-            pass
-        else:
-            if bokeh_prefix:
-                result = (BokehWorker, {"prefix": bokeh_prefix})
-            else:
-                result = BokehWorker
-            services[("bokeh", dashboard_address)] = result
-
     if resources:
         resources = resources.replace(",", " ").split()
         resources = dict(pair.split("=") for pair in resources)
@@ -332,18 +336,6 @@ def main(
             "dask-worker SCHEDULER_ADDRESS:8786"
         )
 
-    if interface:
-        if host:
-            raise ValueError("Can not specify both interface and host")
-        else:
-            host = get_ip_interface(interface)
-
-    if host or port:
-        addr = uri_from_host_port(host, port, 0)
-    else:
-        # Choose appropriate address for scheduler
-        addr = None
-
     if death_timeout is not None:
         death_timeout = parse_timedelta(death_timeout, "s")
 
@@ -351,7 +343,7 @@ def main(
         t(
             scheduler,
             scheduler_file=scheduler_file,
-            ncores=nthreads,
+            nthreads=nthreads,
             services=services,
             loop=loop,
             resources=resources,
@@ -363,6 +355,12 @@ def main(
             preload_argv=preload_argv,
             security=sec,
             contact_address=contact_address,
+            interface=interface,
+            protocol=protocol,
+            host=host,
+            port=port,
+            dashboard_address=dashboard_address if dashboard else None,
+            service_kwargs={"dashboard": {"prefix": dashboard_prefix}},
             name=name if nprocs == 1 or not name else name + "-" + str(i),
             **kwargs
         )
@@ -381,7 +379,7 @@ def main(
 
     @gen.coroutine
     def run():
-        yield [n._start(addr) for n in nannies]
+        yield nannies
         while all(n.status != "closed" for n in nannies):
             yield gen.sleep(0.2)
 
@@ -389,7 +387,10 @@ def main(
 
     try:
         loop.run_sync(run)
-    except (KeyboardInterrupt, TimeoutError):
+    except TimeoutError:
+        # We already log the exception in nanny / worker. Don't do it again.
+        raise TimeoutError("Timed out starting worker.") from None
+    except KeyboardInterrupt:
         pass
     finally:
         logger.info("End worker")
