@@ -18,5 +18,10 @@ def _register_transports():
     from . import inproc
     from . import tcp
 
+    try:
+        from . import ucx
+    except ImportError:
+        pass
+
 
 _register_transports()
