@@ -5,7 +5,7 @@ import pickle
 from collections import defaultdict
 from datetime import timedelta
 import json
-from operator import add, mul
+import operator
 import sys
 from time import sleep
 
@@ -18,7 +18,7 @@ import pytest
 
 from distributed import Nanny, Worker, Client, wait, fire_and_forget
 from distributed.core import connect, rpc
-from distributed.scheduler import Scheduler, BANDWIDTH
+from distributed.scheduler import Scheduler
 from distributed.client import wait
 from distributed.metrics import time
 from distributed.protocol.pickle import dumps
@@ -35,7 +35,6 @@ from distributed.utils_test import (
     cluster,
     div,
     varying,
-    slow,
 )
 from distributed.utils_test import loop, nodebug  # noqa: F401
 from dask.compatibility import apply
@@ -51,11 +50,11 @@ occupancy = defaultdict(lambda: 0)
 def test_administration(s, a, b):
     assert isinstance(s.address, str)
     assert s.address in str(s)
-    assert str(sum(s.ncores.values())) in repr(s)
-    assert str(len(s.ncores)) in repr(s)
+    assert str(sum(s.nthreads.values())) in repr(s)
+    assert str(len(s.nthreads)) in repr(s)
 
 
-@gen_cluster(client=True, ncores=[("127.0.0.1", 1)])
+@gen_cluster(client=True, nthreads=[("127.0.0.1", 1)])
 def test_respect_data_in_memory(c, s, a):
     x = delayed(inc)(1)
     y = delayed(inc)(x)
@@ -64,7 +63,7 @@ def test_respect_data_in_memory(c, s, a):
 
     assert s.tasks[y.key].who_has == {s.workers[a.address]}
 
-    z = delayed(add)(x, y)
+    z = delayed(operator.add)(x, y)
     f2 = c.persist(z)
     while f2.key not in s.tasks or not s.tasks[f2.key]:
         assert s.tasks[y.key].who_has
@@ -107,14 +106,14 @@ def test_decide_worker_with_many_independent_leaves(c, s, a, b):
     assert nhits > 80
 
 
-@gen_cluster(client=True, ncores=[("127.0.0.1", 1)] * 3)
+@gen_cluster(client=True, nthreads=[("127.0.0.1", 1)] * 3)
 def test_decide_worker_with_restrictions(client, s, a, b, c):
     x = client.submit(inc, 1, workers=[a.address, b.address])
     yield wait(x)
     assert x.key in a.data or x.key in b.data
 
 
-@gen_cluster(client=True, ncores=[("127.0.0.1", 1)] * 3)
+@gen_cluster(client=True, nthreads=[("127.0.0.1", 1)] * 3)
 def test_move_data_over_break_restrictions(client, s, a, b, c):
     [x] = yield client.scatter([1], workers=b.address)
     y = client.submit(inc, x, workers=[a.address, b.address])
@@ -122,7 +121,7 @@ def test_move_data_over_break_restrictions(client, s, a, b, c):
     assert y.key in a.data or y.key in b.data
 
 
-@gen_cluster(client=True, ncores=[("127.0.0.1", 1)] * 3)
+@gen_cluster(client=True, nthreads=[("127.0.0.1", 1)] * 3)
 def test_balance_with_restrictions(client, s, a, b, c):
     [x], [y] = yield [
         client.scatter([[1, 2, 3]], workers=a.address),
@@ -134,7 +133,7 @@ def test_balance_with_restrictions(client, s, a, b, c):
     assert s.tasks[z.key].who_has == {s.workers[c.address]}
 
 
-@gen_cluster(client=True, ncores=[("127.0.0.1", 1)] * 3)
+@gen_cluster(client=True, nthreads=[("127.0.0.1", 1)] * 3)
 def test_no_valid_workers(client, s, a, b, c):
     x = client.submit(inc, 1, workers="127.0.0.5:9999")
     while not s.tasks:
@@ -146,7 +145,7 @@ def test_no_valid_workers(client, s, a, b, c):
         yield gen.with_timeout(timedelta(milliseconds=50), x)
 
 
-@gen_cluster(client=True, ncores=[("127.0.0.1", 1)] * 3)
+@gen_cluster(client=True, nthreads=[("127.0.0.1", 1)] * 3)
 def test_no_valid_workers_loose_restrictions(client, s, a, b, c):
     x = client.submit(inc, 1, workers="127.0.0.5:9999", allow_other_workers=True)
 
@@ -154,7 +153,7 @@ def test_no_valid_workers_loose_restrictions(client, s, a, b, c):
     assert result == 2
 
 
-@gen_cluster(client=True, ncores=[])
+@gen_cluster(client=True, nthreads=[])
 def test_no_workers(client, s):
     x = client.submit(inc, 1)
     while not s.tasks:
@@ -166,7 +165,7 @@ def test_no_workers(client, s):
         yield gen.with_timeout(timedelta(milliseconds=50), x)
 
 
-@gen_cluster(ncores=[])
+@gen_cluster(nthreads=[])
 def test_retire_workers_empty(s):
     yield s.retire_workers(workers=[])
 
@@ -208,7 +207,7 @@ def test_remove_worker_from_scheduler(s, a, b):
 
     assert a.address in s.stream_comms
     s.remove_worker(address=a.address)
-    assert a.address not in s.ncores
+    assert a.address not in s.nthreads
     assert len(s.workers[b.address].processing) == len(dsk)  # b owns everything
     s.validate_state()
 
@@ -216,14 +215,14 @@ def test_remove_worker_from_scheduler(s, a, b):
 @gen_cluster(config={"distributed.scheduler.events-cleanup-delay": "10 ms"})
 def test_clear_events_worker_removal(s, a, b):
     assert a.address in s.events
-    assert a.address in s.ncores
+    assert a.address in s.nthreads
     assert b.address in s.events
-    assert b.address in s.ncores
+    assert b.address in s.nthreads
 
     s.remove_worker(address=a.address)
     # Shortly after removal, the events should still be there
     assert a.address in s.events
-    assert a.address not in s.ncores
+    assert a.address not in s.nthreads
     s.validate_state()
 
     start = time()
@@ -254,7 +253,7 @@ def test_clear_events_client_removal(c, s, a, b):
 
 @gen_cluster()
 def test_add_worker(s, a, b):
-    w = Worker(s.ip, s.port, ncores=3)
+    w = Worker(s.address, nthreads=3)
     w.data["x-5"] = 6
     w.data["y"] = 1
     yield w
@@ -268,7 +267,7 @@ def test_add_worker(s, a, b):
     )
 
     s.add_worker(
-        address=w.address, keys=list(w.data), ncores=w.ncores, services=s.services
+        address=w.address, keys=list(w.data), nthreads=w.nthreads, services=s.services
     )
 
     s.validate_state()
@@ -390,7 +389,7 @@ def test_delete_data(c, s, a, b):
         assert time() < start + 5
 
 
-@gen_cluster(client=True, ncores=[("127.0.0.1", 1)])
+@gen_cluster(client=True, nthreads=[("127.0.0.1", 1)])
 def test_delete(c, s, a):
     x = c.submit(inc, 1)
     yield x
@@ -428,7 +427,10 @@ def test_filtered_communication(s, a, b):
     yield f.write(
         {
             "op": "update-graph",
-            "tasks": {"x": dumps_task((inc, 1)), "z": dumps_task((add, "x", 10))},
+            "tasks": {
+                "x": dumps_task((inc, 1)),
+                "z": dumps_task((operator.add, "x", 10)),
+            },
             "dependencies": {"x": [], "z": ["x"]},
             "client": "f",
             "keys": ["z"],
@@ -479,12 +481,12 @@ def test_ready_remove_worker(s, a, b):
         dependencies={"x-%d" % i: [] for i in range(20)},
     )
 
-    assert all(len(w.processing) > w.ncores for w in s.workers.values())
+    assert all(len(w.processing) > w.nthreads for w in s.workers.values())
 
     s.remove_worker(address=a.address)
 
     assert set(s.workers) == {b.address}
-    assert all(len(w.processing) > w.ncores for w in s.workers.values())
+    assert all(len(w.processing) > w.nthreads for w in s.workers.values())
 
 
 @gen_cluster(client=True, Worker=Nanny)
@@ -533,14 +535,13 @@ def test_broadcast_nanny(s, a, b):
 
 @gen_test()
 def test_worker_name():
-    s = Scheduler(validate=True)
-    s.start(0)
-    w = yield Worker(s.ip, s.port, name="alice")
+    s = yield Scheduler(validate=True, port=0)
+    w = yield Worker(s.address, name="alice")
     assert s.workers[w.address].name == "alice"
     assert s.aliases["alice"] == w.address
 
     with pytest.raises(ValueError):
-        w2 = yield Worker(s.ip, s.port, name="alice")
+        w2 = yield Worker(s.address, name="alice")
         yield w2.close()
 
     yield w.close()
@@ -550,11 +551,10 @@ def test_worker_name():
 @gen_test()
 def test_coerce_address():
     with dask.config.set({"distributed.comm.timeouts.connect": "100ms"}):
-        s = Scheduler(validate=True)
-        s.start(0)
+        s = yield Scheduler(validate=True, port=0)
         print("scheduler:", s.address, s.listen_address)
-        a = Worker(s.ip, s.port, name="alice")
-        b = Worker(s.ip, s.port, name=123)
+        a = Worker(s.address, name="alice")
+        b = Worker(s.address, name=123)
         c = Worker("127.0.0.1", s.port, name="charlie")
         yield [a, b, c]
 
@@ -591,13 +591,13 @@ def test_coerce_address():
 @pytest.mark.skipif(
     sys.platform.startswith("win"), reason="file descriptors not really a thing"
 )
-@gen_cluster(ncores=[])
+@gen_cluster(nthreads=[])
 def test_file_descriptors_dont_leak(s):
     psutil = pytest.importorskip("psutil")
     proc = psutil.Process()
     before = proc.num_fds()
 
-    w = yield Worker(s.ip, s.port)
+    w = yield Worker(s.address)
     yield w.close()
 
     during = proc.num_fds()
@@ -624,12 +624,12 @@ def test_update_graph_culls(s, a, b):
     assert "z" not in s.dependencies
 
 
-@gen_cluster(ncores=[])
+@gen_cluster(nthreads=[])
 def test_add_worker_is_idempotent(s):
-    s.add_worker(address=alice, ncores=1, resolve_address=False)
-    ncores = dict(s.ncores)
+    s.add_worker(address=alice, nthreads=1, resolve_address=False)
+    nthreads = dict(s.nthreads)
     s.add_worker(address=alice, resolve_address=False)
-    assert s.ncores == s.ncores
+    assert s.nthreads == s.nthreads
 
 
 def test_io_loop(loop):
@@ -654,7 +654,7 @@ def test_story(c, s, a, b):
     assert len(s.story(x.key, y.key)) > len(story)
 
 
-@gen_cluster(ncores=[], client=True)
+@gen_cluster(nthreads=[], client=True)
 def test_scatter_no_workers(c, s):
     with pytest.raises(gen.TimeoutError):
         yield s.scatter(data={"x": 1}, client="alice", timeout=0.1)
@@ -664,16 +664,16 @@ def test_scatter_no_workers(c, s):
         yield c.scatter(123, timeout=0.1)
     assert time() < start + 1.5
 
-    w = Worker(s.ip, s.port, ncores=3)
+    w = Worker(s.address, nthreads=3)
     yield [c.scatter(data={"y": 2}, timeout=5), w._start()]
 
     assert w.data["y"] == 2
     yield w.close()
 
 
-@gen_cluster(ncores=[])
+@gen_cluster(nthreads=[])
 def test_scheduler_sees_memory_limits(s):
-    w = yield Worker(s.ip, s.port, ncores=3, memory_limit=12345)
+    w = yield Worker(s.address, nthreads=3, memory_limit=12345)
 
     assert s.workers[w.address].memory_limit == 12345
     yield w.close()
@@ -688,8 +688,8 @@ def test_retire_workers(c, s, a, b):
 
     workers = yield s.retire_workers()
     assert list(workers) == [a.address]
-    assert workers[a.address]["ncores"] == a.ncores
-    assert list(s.ncores) == [b.address]
+    assert workers[a.address]["nthreads"] == a.nthreads
+    assert list(s.nthreads) == [b.address]
 
     assert s.workers_to_close() == []
 
@@ -717,7 +717,7 @@ def test_retire_workers_n(c, s, a, b):
         yield gen.sleep(0.01)
 
 
-@gen_cluster(client=True, ncores=[("127.0.0.1", 1)] * 4)
+@gen_cluster(client=True, nthreads=[("127.0.0.1", 1)] * 4)
 def test_workers_to_close(cl, s, *workers):
     s.task_duration["a"] = 4
     s.task_duration["b"] = 4
@@ -732,7 +732,7 @@ def test_workers_to_close(cl, s, *workers):
     assert len(wtc) == 1
 
 
-@gen_cluster(client=True, ncores=[("127.0.0.1", 1)] * 4)
+@gen_cluster(client=True, nthreads=[("127.0.0.1", 1)] * 4)
 def test_workers_to_close_grouped(c, s, *workers):
     groups = {
         workers[0].address: "a",
@@ -777,12 +777,12 @@ def test_retire_workers_no_suspicious_tasks(c, s, a, b):
     assert all(ts.suspicious == 0 for ts in s.tasks.values())
 
 
-@slow
+@pytest.mark.slow
 @pytest.mark.skipif(
     sys.platform.startswith("win"), reason="file descriptors not really a thing"
 )
 @pytest.mark.skipif(sys.version_info < (3, 6), reason="intermittent failure")
-@gen_cluster(client=True, ncores=[], timeout=240)
+@gen_cluster(client=True, nthreads=[], timeout=240)
 def test_file_descriptors(c, s):
     yield gen.sleep(0.1)
     psutil = pytest.importorskip("psutil")
@@ -791,9 +791,9 @@ def test_file_descriptors(c, s):
     num_fds_1 = proc.num_fds()
 
     N = 20
-    nannies = yield [Nanny(s.ip, s.port, loop=s.loop) for i in range(N)]
+    nannies = yield [Nanny(s.address, loop=s.loop) for i in range(N)]
 
-    while len(s.ncores) < N:
+    while len(s.nthreads) < N:
         yield gen.sleep(0.1)
 
     num_fds_2 = proc.num_fds()
@@ -822,9 +822,12 @@ def test_file_descriptors(c, s):
     assert num_fds_6 < num_fds_5 + N
 
     yield [n.close() for n in nannies]
+    yield c.close()
 
     assert not s.rpc.open
-    assert not c.rpc.active
+    for addr, occ in c.rpc.occupied.items():
+        for comm in occ:
+            assert comm.closed() or comm.peer_address != s.address, comm
     assert not s.stream_comms
 
     start = time()
@@ -833,7 +836,7 @@ def test_file_descriptors(c, s):
         assert time() < start + 3
 
 
-@slow
+@pytest.mark.slow
 @nodebug
 @gen_cluster(client=True)
 def test_learn_occupancy(c, s, a, b):
@@ -846,7 +849,7 @@ def test_learn_occupancy(c, s, a, b):
         assert 50 < s.workers[w.address].occupancy < 700
 
 
-@slow
+@pytest.mark.slow
 @nodebug
 @gen_cluster(client=True)
 def test_learn_occupancy_2(c, s, a, b):
@@ -873,7 +876,7 @@ def test_occupancy_cleardown(c, s, a, b):
 
 
 @nodebug
-@gen_cluster(client=True, ncores=[("127.0.0.1", 1)] * 30)
+@gen_cluster(client=True, nthreads=[("127.0.0.1", 1)] * 30)
 def test_balance_many_workers(c, s, *workers):
     futures = c.map(slowinc, range(20), delay=0.2)
     yield wait(futures)
@@ -881,7 +884,7 @@ def test_balance_many_workers(c, s, *workers):
 
 
 @nodebug
-@gen_cluster(client=True, ncores=[("127.0.0.1", 1)] * 30)
+@gen_cluster(client=True, nthreads=[("127.0.0.1", 1)] * 30)
 def test_balance_many_workers_2(c, s, *workers):
     s.extensions["stealing"]._pc.callback_time = 100000000
     futures = c.map(slowinc, range(90), delay=0.2)
@@ -904,8 +907,8 @@ def test_learn_occupancy_multiple_workers(c, s, a, b):
 @gen_cluster(client=True)
 def test_include_communication_in_occupancy(c, s, a, b):
     s.task_duration["slowadd"] = 0.001
-    x = c.submit(mul, b"0", int(BANDWIDTH), workers=a.address)
-    y = c.submit(mul, b"1", int(BANDWIDTH * 1.5), workers=b.address)
+    x = c.submit(operator.mul, b"0", int(s.bandwidth), workers=a.address)
+    y = c.submit(operator.mul, b"1", int(s.bandwidth * 1.5), workers=b.address)
 
     z = c.submit(slowadd, x, y, delay=1)
     while z.key not in s.tasks or not s.tasks[z.key].processing_on:
@@ -929,7 +932,7 @@ def test_worker_arrives_with_processing_data(c, s, a, b):
     while not any(w.processing for w in s.workers.values()):
         yield gen.sleep(0.01)
 
-    w = Worker(s.ip, s.port, ncores=1)
+    w = Worker(s.address, nthreads=1)
     w.put_key_in_memory(y.key, 3)
 
     yield w
@@ -948,7 +951,7 @@ def test_worker_arrives_with_processing_data(c, s, a, b):
     yield w.close()
 
 
-@gen_cluster(client=True, ncores=[("127.0.0.1", 1)])
+@gen_cluster(client=True, nthreads=[("127.0.0.1", 1)])
 def test_worker_breaks_and_returns(c, s, a):
     future = c.submit(slowinc, 1, delay=0.1)
     for i in range(10):
@@ -969,7 +972,7 @@ def test_worker_breaks_and_returns(c, s, a):
     assert states == {"memory": 1, "released": 10}
 
 
-@gen_cluster(client=True, ncores=[])
+@gen_cluster(client=True, nthreads=[])
 def test_no_workers_to_memory(c, s):
     x = delayed(slowinc)(1, delay=0.4)
     y = delayed(slowinc)(x, delay=0.4)
@@ -980,7 +983,7 @@ def test_no_workers_to_memory(c, s):
     while not s.tasks:
         yield gen.sleep(0.01)
 
-    w = Worker(s.ip, s.port, ncores=1)
+    w = Worker(s.address, nthreads=1)
     w.put_key_in_memory(y.key, 3)
 
     yield w
@@ -1010,7 +1013,7 @@ def test_no_worker_to_memory_restrictions(c, s, a, b):
     while not s.tasks:
         yield gen.sleep(0.01)
 
-    w = Worker(s.ip, s.port, ncores=1, name="alice")
+    w = Worker(s.address, nthreads=1, name="alice")
     w.put_key_in_memory(y.key, 3)
 
     yield w
@@ -1064,7 +1067,7 @@ def test_close_worker(c, s, a, b):
     assert len(s.workers) == 1
 
 
-@slow
+@pytest.mark.slow
 @gen_cluster(client=True, Worker=Nanny, timeout=20)
 def test_close_nanny(c, s, a, b):
     assert len(s.workers) == 2
@@ -1119,7 +1122,7 @@ def test_retire_nannies_close(c, s, a, b):
     assert not s.workers
 
 
-@gen_cluster(client=True, ncores=[("127.0.0.1", 2)])
+@gen_cluster(client=True, nthreads=[("127.0.0.1", 2)])
 def test_fifo_submission(c, s, w):
     futures = []
     for i in range(20):
@@ -1133,28 +1136,28 @@ def test_fifo_submission(c, s, w):
 @gen_test()
 def test_scheduler_file():
     with tmpfile() as fn:
-        s = Scheduler(scheduler_file=fn)
-        s.start(0)
+        s = yield Scheduler(scheduler_file=fn, port=0)
         with open(fn) as f:
             data = json.load(f)
         assert data["address"] == s.address
 
         c = yield Client(scheduler_file=fn, loop=s.loop, asynchronous=True)
-    yield s.close()
+        yield c.close()
+        yield s.close()
 
 
 @pytest.mark.xfail(reason="")
-@gen_cluster(client=True, ncores=[])
+@gen_cluster(client=True, nthreads=[])
 def test_non_existent_worker(c, s):
     with dask.config.set({"distributed.comm.timeouts.connect": "100ms"}):
-        s.add_worker(address="127.0.0.1:5738", ncores=2, nbytes={}, host_info={})
+        s.add_worker(address="127.0.0.1:5738", nthreads=2, nbytes={}, host_info={})
         futures = c.map(inc, range(10))
         yield gen.sleep(0.300)
         assert not s.workers
         assert all(ts.state == "no-worker" for ts in s.tasks.values())
 
 
-@gen_cluster(client=True, ncores=[("127.0.0.1", 1)] * 3)
+@gen_cluster(client=True, nthreads=[("127.0.0.1", 1)] * 3)
 def test_correct_bad_time_estimate(c, s, *workers):
     future = c.submit(slowinc, 1, delay=0)
     yield wait(future)
@@ -1171,7 +1174,7 @@ def test_correct_bad_time_estimate(c, s, *workers):
 @gen_test()
 def test_service_hosts():
     pytest.importorskip("bokeh")
-    from distributed.bokeh.scheduler import BokehScheduler
+    from distributed.dashboard import BokehScheduler
 
     port = 0
     for url, expected in [
@@ -1179,12 +1182,12 @@ def test_service_hosts():
         ("tcp://127.0.0.1", "127.0.0.1"),
         ("tcp://127.0.0.1:38275", "127.0.0.1"),
     ]:
-        services = {("bokeh", port): BokehScheduler}
+        services = {("dashboard", port): BokehScheduler}
 
         s = Scheduler(services=services)
         yield s.start(url)
 
-        sock = first(s.services["bokeh"].server._http._sockets.values())
+        sock = first(s.services["dashboard"].server._http._sockets.values())
         if isinstance(expected, tuple):
             assert sock.getsockname()[0] in expected
         else:
@@ -1193,12 +1196,12 @@ def test_service_hosts():
 
     port = ("127.0.0.1", 0)
     for url in ["tcp://0.0.0.0", "tcp://127.0.0.1", "tcp://127.0.0.1:38275"]:
-        services = {("bokeh", port): BokehScheduler}
+        services = {("dashboard", port): BokehScheduler}
 
         s = Scheduler(services=services)
         yield s.start(url)
 
-        sock = first(s.services["bokeh"].server._http._sockets.values())
+        sock = first(s.services["dashboard"].server._http._sockets.values())
         assert sock.getsockname()[0] == "127.0.0.1"
         yield s.close()
 
@@ -1252,7 +1255,7 @@ def test_log_tasks_during_restart(c, s, a, b):
     assert "exit" in str(s.events)
 
 
-@gen_cluster(client=True, ncores=[("127.0.0.1", 1)] * 2)
+@gen_cluster(client=True, nthreads=[("127.0.0.1", 1)] * 2)
 def test_reschedule(c, s, a, b):
     yield c.submit(slowinc, -1, delay=0.1)  # learn cost
     x = c.map(slowinc, range(4), delay=0.1)
@@ -1321,7 +1324,7 @@ def test_retries(c, s, a, b):
 
 
 @pytest.mark.xfail(reason="second worker also errant for some reason")
-@gen_cluster(client=True, ncores=[("127.0.0.1", 1)] * 3, timeout=5)
+@gen_cluster(client=True, nthreads=[("127.0.0.1", 1)] * 3, timeout=5)
 def test_mising_data_errant_worker(c, s, w1, w2, w3):
     with dask.config.set({"distributed.comm.timeouts.connect": "1s"}):
         np = pytest.importorskip("numpy")
@@ -1377,7 +1380,7 @@ def test_dont_recompute_if_persisted_3(c, s, a, b):
     x = delayed(inc)(1, dask_key_name="x")
     y = delayed(inc)(2, dask_key_name="y")
     z = delayed(inc)(y, dask_key_name="z")
-    w = delayed(add)(x, z, dask_key_name="w")
+    w = delayed(operator.add)(x, z, dask_key_name="w")
 
     ww = w.persist()
     yield wait(ww)
@@ -1454,7 +1457,7 @@ def test_closing_scheduler_closes_workers(s, a, b):
 
 
 @gen_cluster(
-    client=True, ncores=[("127.0.0.1", 1)], worker_kwargs={"resources": {"A": 1}}
+    client=True, nthreads=[("127.0.0.1", 1)], worker_kwargs={"resources": {"A": 1}}
 )
 def test_resources_reset_after_cancelled_task(c, s, w):
     future = c.submit(sleep, 0.2, resources={"A": 1})
@@ -1515,6 +1518,17 @@ def test_idle_timeout(c, s, a, b):
     assert b.status == "closed"
 
 
+@gen_cluster(client=True, config={"distributed.scheduler.bandwidth": "100 GB"})
+def test_bandwidth(c, s, a, b):
+    start = s.bandwidth
+    x = c.submit(operator.mul, b"0", 20000, workers=a.address)
+    y = c.submit(lambda x: x, x, workers=b.address)
+    yield y
+    yield b.heartbeat()
+    assert s.bandwidth < start  # we've learned that we're slower
+    assert b.latency
+
+
 @gen_cluster()
 def test_workerstate_clean(s, a, b):
     ws = s.workers[a.address].clean()
@@ -1536,3 +1550,74 @@ def test_close_workers(s, a, b):
     yield s.close(close_workers=True)
     assert a.status == "closed"
     assert b.status == "closed"
+
+
+@pytest.mark.skipif(
+    not sys.platform.startswith("linux"), reason="Need 127.0.0.2 to mean localhost"
+)
+@gen_test()
+def test_host_address():
+    s = yield Scheduler(host="127.0.0.2", port=0)
+    assert "127.0.0.2" in s.address
+    yield s.close()
+
+
+@gen_test()
+def test_dashboard_address():
+    pytest.importorskip("bokeh")
+    s = yield Scheduler(dashboard_address="127.0.0.1:8901", port=0)
+    assert s.services["dashboard"].port == 8901
+    yield s.close()
+
+    s = yield Scheduler(dashboard_address="127.0.0.1", port=0)
+    assert s.services["dashboard"].port
+    yield s.close()
+
+
+@gen_cluster(client=True)
+async def test_adaptive_target(c, s, a, b):
+    assert s.adaptive_target() == 0
+    x = c.submit(inc, 1)
+    await x
+    assert s.adaptive_target() == 1
+
+    # Long task
+    s.task_duration["slowinc"] = 10
+    x = c.submit(slowinc, 1, delay=0.5)
+    while x.key not in s.tasks:
+        await gen.sleep(0.01)
+    assert s.adaptive_target(target_duration=".1s") == 1  # still one
+
+    s.task_duration["slowinc"] = 10
+    L = c.map(slowinc, range(100), delay=0.5)
+    while len(s.tasks) < 100:
+        await gen.sleep(0.01)
+    assert 10 < s.adaptive_target(target_duration=".1s") <= 100
+    del x, L
+    while s.tasks:
+        await gen.sleep(0.01)
+    assert s.adaptive_target(target_duration=".1s") == 0
+
+
+@pytest.mark.asyncio
+async def test_async_context_manager():
+    async with Scheduler(port=0) as s:
+        assert s.status == "running"
+        async with Worker(s.address) as w:
+            assert w.status == "running"
+            assert s.workers
+        assert not s.workers
+
+
+@pytest.mark.asyncio
+async def test_allowed_failures_config():
+    async with Scheduler(port=0, allowed_failures=10) as s:
+        assert s.allowed_failures == 10
+
+    with dask.config.set({"distributed.scheduler.allowed_failures": 100}):
+        async with Scheduler(port=0) as s:
+            assert s.allowed_failures == 100
+
+    with dask.config.set({"distributed.scheduler.allowed_failures": 0}):
+        async with Scheduler(port=0) as s:
+            assert s.allowed_failures == 0
