@@ -61,7 +61,7 @@ def _worker(executor, work_queue):
                 return
         del executor
     except BaseException:
-        logger.critical('Exception in worker', exc_info=True)
+        logger.critical("Exception in worker", exc_info=True)
     finally:
         del thread_state.proceed
         del thread_state.executor
@@ -75,13 +75,18 @@ class ThreadPoolExecutor(thread.ThreadPoolExecutor):
         super(ThreadPoolExecutor, self).__init__(*args, **kwargs)
         self._rejoin_list = []
         self._rejoin_lock = threading.Lock()
-        self._thread_name_prefix = kwargs.get('thread_name_prefix', 'DaskThreadPoolExecutor')
+        self._thread_name_prefix = kwargs.get(
+            "thread_name_prefix", "DaskThreadPoolExecutor"
+        )
 
     def _adjust_thread_count(self):
         if len(self._threads) < self._max_workers:
-            t = threading.Thread(target=_worker,
-                                 name=self._thread_name_prefix + "-%d-%d" % (os.getpid(), next(self._counter)),
-                                 args=(self, self._work_queue))
+            t = threading.Thread(
+                target=_worker,
+                name=self._thread_name_prefix
+                + "-%d-%d" % (os.getpid(), next(self._counter)),
+                args=(self, self._work_queue),
+            )
             t.daemon = True
             self._threads.add(t)
             t.start()
